module.exports = defineTest({
	description: 'default export of anonymous function'
});
